@@ -18,7 +18,7 @@
 
 #include <boost/test/included/unit_test.hpp>
 
-#include <boost/bind.hpp>
+#include <boost/bind/bind.hpp>
 
 #ifdef HAVE_BOOST_ASIO
 #include <boost/asio.hpp>
@@ -34,19 +34,18 @@ using detail::kMinBlockSize;
 using std::cout;
 using std::endl;
 
+// Make a string of repeating 0123456789ABCDEF0123456789...
 std::string makeString(size_t len) {
-    std::string newstring;
-    newstring.reserve(len);
+    std::string result;
+    result.reserve(len);
+
+    constexpr char chars[] = "0123456789ABCDEF";
 
     for (size_t i = 0; i < len; ++i) {
-        char newchar = '0' + i % 16;
-        if (newchar > '9') {
-            newchar += 7;
-        }
-        newstring.push_back(newchar);
+        result.push_back(chars[i % 16]);
     }
 
-    return newstring;
+    return result;
 }
 
 void printBuffer(const InputBuffer &buf) {
@@ -219,7 +218,7 @@ void TestDiscard() {
             BOOST_CHECK_EQUAL(ob.freeSpace(), kDefaultBlockSize / 2);
             BOOST_CHECK_EQUAL(ob.numChunks(), 1);
 
-            int chunks = 3 - (discarded / kDefaultBlockSize);
+            size_t chunks = 3 - (discarded / kDefaultBlockSize);
             BOOST_CHECK_EQUAL(ob.numDataChunks(), chunks);
         }
 
@@ -331,7 +330,7 @@ void TestExtractToInput() {
             BOOST_CHECK_EQUAL(ob.freeSpace(), kDefaultBlockSize / 2);
             BOOST_CHECK_EQUAL(ob.numChunks(), 1);
 
-            int chunks = 3 - (extracted / kDefaultBlockSize);
+            size_t chunks = 3 - (extracted / kDefaultBlockSize);
             BOOST_CHECK_EQUAL(ob.numDataChunks(), chunks);
         }
 
@@ -526,7 +525,7 @@ void TestSeek() {
         avro::InputBuffer buf(tmp1);
 
         cout << "Starting string: " << str << '\n';
-        BOOST_CHECK_EQUAL(static_cast<std::string::size_type>(buf.size()), str.size());
+        BOOST_CHECK_EQUAL(buf.size(), str.size());
 
         avro::istream is(buf);
 
