@@ -1,4 +1,4 @@
-﻿/*
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -45,6 +45,14 @@ namespace Avro.IO
             public JsonReader OrigParser { get; set; }
         }
 
+        private sealed class AvroJsonTextReader : JsonTextReader
+        {
+            public AvroJsonTextReader(TextReader reader) : base(reader)
+            {
+                this.DateParseHandling = DateParseHandling.None;
+            }
+        }
+
         private JsonDecoder(Symbol root, Stream stream) : base(root)
         {
             Configure(stream);
@@ -85,7 +93,7 @@ namespace Avro.IO
             Parser.Reset();
             reorderBuffers.Clear();
             currentReorderBuffer = null;
-            reader = new JsonTextReader(new StreamReader(stream));
+            reader = new AvroJsonTextReader(new StreamReader(stream));
             reader.Read();
         }
 
@@ -100,7 +108,7 @@ namespace Avro.IO
             Parser.Reset();
             reorderBuffers.Clear();
             currentReorderBuffer = null;
-            reader = new JsonTextReader(new StringReader(str));
+            reader = new AvroJsonTextReader(new StringReader(str));
             reader.Read();
         }
 
@@ -182,10 +190,25 @@ namespace Avro.IO
                 reader.Read();
                 return result;
             }
-            else
+            else if (reader.TokenType == JsonToken.String)
             {
-                throw TypeError("float");
+                string str = Convert.ToString(reader.Value);
+                reader.Read();
+                if (IsNaNString(str))
+                {
+                    return float.NaN;
+                }
+                else if (IsPositiveInfinityString(str))
+                {
+                    return float.PositiveInfinity;
+                }
+                else if (IsNegativeInfinityString(str))
+                {
+                    return float.NegativeInfinity;
+                }
             }
+
+            throw TypeError("float");
         }
 
         /// <inheritdoc />
@@ -198,10 +221,25 @@ namespace Avro.IO
                 reader.Read();
                 return result;
             }
-            else
+            else if (reader.TokenType == JsonToken.String)
             {
-                throw TypeError("double");
+                string str = Convert.ToString(reader.Value);
+                reader.Read();
+                if (IsNaNString(str))
+                {
+                    return double.NaN;
+                }
+                else if (IsPositiveInfinityString(str))
+                {
+                    return double.PositiveInfinity;
+                }
+                else if (IsNegativeInfinityString(str))
+                {
+                    return double.NegativeInfinity;
+                }
             }
+
+            throw TypeError("double");
         }
 
         /// <inheritdoc />
@@ -651,7 +689,7 @@ namespace Avro.IO
                     if (currentReorderBuffer != null && currentReorderBuffer.SavedFields.Count > 0)
                     {
                         throw TypeError("Unknown fields: " + currentReorderBuffer.SavedFields.Keys
-                            .Aggregate((x, y) => x + ", " + y ));
+                            .Aggregate((x, y) => x + ", " + y));
                     }
 
                     currentReorderBuffer = reorderBuffers.Pop();
@@ -735,6 +773,7 @@ namespace Avro.IO
             public JsonElementReader(IList<JsonElement> elements)
             {
                 this.elements = elements;
+                this.DateParseHandling = DateParseHandling.None;
                 pos = 0;
             }
 
@@ -757,6 +796,23 @@ namespace Avro.IO
             }
         }
 
+        private bool IsNaNString(string str)
+        {
+            return str.Equals("NaN", StringComparison.Ordinal);
+        }
+
+        private bool IsPositiveInfinityString(string str)
+        {
+            return str.Equals("Infinity", StringComparison.Ordinal) ||
+                   str.Equals("INF", StringComparison.Ordinal);
+        }
+
+        private bool IsNegativeInfinityString(string str)
+        {
+            return str.Equals("-Infinity", StringComparison.Ordinal) ||
+                   str.Equals("-INF", StringComparison.Ordinal);
+        }
+
         private AvroTypeException TypeError(string type)
         {
             return new AvroTypeException("Expected " + type + ". Got " + reader.TokenType);
