@@ -17,14 +17,14 @@
  */
 package org.apache.avro.util.internal;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 import static org.hamcrest.CoreMatchers.*;
 import static org.hamcrest.MatcherAssert.assertThat;
 
 public class TestClassValueCache {
   @Test
-  public void testBasic() {
+  void basic() {
     ClassValueCache<String> cache = new ClassValueCache<>(Class::toString);
 
     String fromCache = cache.apply(String.class);
