@@ -78,9 +78,7 @@ import static org.apache.avro.TestSchemas.STRING_SCHEMA;
 import static org.apache.avro.TestSchemas.STRING_UNION_SCHEMA;
 import static org.apache.avro.TestSchemas.assertSchemaContains;
 import static org.apache.avro.TestSchemas.list;
-import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertNull;
+import static org.junit.jupiter.api.Assertions.*;
 
 import java.io.BufferedReader;
 import java.io.ByteArrayOutputStream;
@@ -105,7 +103,7 @@ import org.apache.avro.io.DecoderFactory;
 import org.apache.avro.io.Encoder;
 import org.apache.avro.io.EncoderFactory;
 import org.apache.avro.util.Utf8;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -120,9 +118,9 @@ public class TestSchemaCompatibility {
       new Schema.Field("oldfield1", INT_SCHEMA, null, null), new Schema.Field("oldfield2", STRING_SCHEMA, null, null)));
 
   @Test
-  public void testValidateSchemaPairMissingField() {
+  void validateSchemaPairMissingField() {
     final List<Field> readerFields = list(new Schema.Field("oldfield1", INT_SCHEMA, null, null));
-    final Schema reader = Schema.createRecord(readerFields);
+    final Schema reader = Schema.createRecord(null, null, null, false, readerFields);
     final SchemaCompatibility.SchemaPairCompatibility expectedResult = new SchemaCompatibility.SchemaPairCompatibility(
         SchemaCompatibility.SchemaCompatibilityResult.compatible(), reader, WRITER_SCHEMA,
         SchemaCompatibility.READER_WRITER_COMPATIBLE_MESSAGE);
@@ -132,9 +130,9 @@ public class TestSchemaCompatibility {
   }
 
   @Test
-  public void testValidateSchemaPairMissingSecondField() {
+  void validateSchemaPairMissingSecondField() {
     final List<Schema.Field> readerFields = list(new Schema.Field("oldfield2", STRING_SCHEMA, null, null));
-    final Schema reader = Schema.createRecord(readerFields);
+    final Schema reader = Schema.createRecord(null, null, null, false, readerFields);
     final SchemaCompatibility.SchemaPairCompatibility expectedResult = new SchemaCompatibility.SchemaPairCompatibility(
         SchemaCompatibility.SchemaCompatibilityResult.compatible(), reader, WRITER_SCHEMA,
         SchemaCompatibility.READER_WRITER_COMPATIBLE_MESSAGE);
@@ -144,10 +142,10 @@ public class TestSchemaCompatibility {
   }
 
   @Test
-  public void testValidateSchemaPairAllFields() {
+  void validateSchemaPairAllFields() {
     final List<Schema.Field> readerFields = list(new Schema.Field("oldfield1", INT_SCHEMA, null, null),
         new Schema.Field("oldfield2", STRING_SCHEMA, null, null));
-    final Schema reader = Schema.createRecord(readerFields);
+    final Schema reader = Schema.createRecord(null, null, null, false, readerFields);
     final SchemaCompatibility.SchemaPairCompatibility expectedResult = new SchemaCompatibility.SchemaPairCompatibility(
         SchemaCompatibility.SchemaCompatibilityResult.compatible(), reader, WRITER_SCHEMA,
         SchemaCompatibility.READER_WRITER_COMPATIBLE_MESSAGE);
@@ -157,10 +155,10 @@ public class TestSchemaCompatibility {
   }
 
   @Test
-  public void testValidateSchemaNewFieldWithDefault() {
+  void validateSchemaNewFieldWithDefault() {
     final List<Schema.Field> readerFields = list(new Schema.Field("oldfield1", INT_SCHEMA, null, null),
         new Schema.Field("newfield1", INT_SCHEMA, null, 42));
-    final Schema reader = Schema.createRecord(readerFields);
+    final Schema reader = Schema.createRecord(null, null, null, false, readerFields);
     final SchemaCompatibility.SchemaPairCompatibility expectedResult = new SchemaCompatibility.SchemaPairCompatibility(
         SchemaCompatibility.SchemaCompatibilityResult.compatible(), reader, WRITER_SCHEMA,
         SchemaCompatibility.READER_WRITER_COMPATIBLE_MESSAGE);
@@ -170,10 +168,10 @@ public class TestSchemaCompatibility {
   }
 
   @Test
-  public void testValidateSchemaNewField() {
+  void validateSchemaNewField() {
     final List<Schema.Field> readerFields = list(new Schema.Field("oldfield1", INT_SCHEMA, null, null),
         new Schema.Field("newfield1", INT_SCHEMA, null, null));
-    final Schema reader = Schema.createRecord(readerFields);
+    final Schema reader = Schema.createRecord(null, null, null, false, readerFields);
     SchemaPairCompatibility compatibility = checkReaderWriterCompatibility(reader, WRITER_SCHEMA);
 
     // Test new field without default value.
@@ -189,7 +187,7 @@ public class TestSchemaCompatibility {
   }
 
   @Test
-  public void testValidateArrayWriterSchema() {
+  void validateArrayWriterSchema() {
     final Schema validReader = Schema.createArray(STRING_SCHEMA);
     final Schema invalidReader = Schema.createMap(STRING_SCHEMA);
     final SchemaCompatibility.SchemaPairCompatibility validResult = new SchemaCompatibility.SchemaPairCompatibility(
@@ -209,7 +207,7 @@ public class TestSchemaCompatibility {
   }
 
   @Test
-  public void testValidatePrimitiveWriterSchema() {
+  void validatePrimitiveWriterSchema() {
     final Schema validReader = Schema.create(Schema.Type.STRING);
     final SchemaCompatibility.SchemaPairCompatibility validResult = new SchemaCompatibility.SchemaPairCompatibility(
         SchemaCompatibility.SchemaCompatibilityResult.compatible(), validReader, STRING_SCHEMA,
@@ -230,11 +228,27 @@ public class TestSchemaCompatibility {
    * Reader union schema must contain all writer union branches.
    */
   @Test
-  public void testUnionReaderWriterSubsetIncompatibility() {
+  void unionReaderWriterSubsetIncompatibility() {
     final Schema unionWriter = Schema.createUnion(list(INT_SCHEMA, STRING_SCHEMA, LONG_SCHEMA));
     final Schema unionReader = Schema.createUnion(list(INT_SCHEMA, STRING_SCHEMA));
     final SchemaPairCompatibility result = checkReaderWriterCompatibility(unionReader, unionWriter);
     assertEquals(SchemaCompatibilityType.INCOMPATIBLE, result.getType());
+    assertEquals("/2", result.getResult().getIncompatibilities().get(0).getLocation());
+  }
+
+  @Test
+  void unionWriterSimpleReaderIncompatibility() {
+    Schema mandatorySchema = SchemaBuilder.record("Account").fields().name("age").type().intType().noDefault()
+        .endRecord();
+    Schema optionalSchema = SchemaBuilder.record("Account").fields().optionalInt("age").endRecord();
+
+    SchemaPairCompatibility compatibility = checkReaderWriterCompatibility(mandatorySchema, optionalSchema);
+
+    assertEquals(SchemaCompatibilityType.INCOMPATIBLE, compatibility.getType());
+
+    Incompatibility incompatibility = compatibility.getResult().getIncompatibilities().get(0);
+    assertEquals("reader type: INT not compatible with writer type: NULL", incompatibility.getMessage());
+    assertEquals("/fields/0/type/0", incompatibility.getLocation());
   }
 
   // -----------------------------------------------------------------------------------------------
@@ -371,14 +385,14 @@ public class TestSchemaCompatibility {
    * Tests reader/writer compatibility validation.
    */
   @Test
-  public void testReaderWriterCompatibility() {
+  void readerWriterCompatibility() {
     for (ReaderWriter readerWriter : COMPATIBLE_READER_WRITER_TEST_CASES) {
       final Schema reader = readerWriter.getReader();
       final Schema writer = readerWriter.getWriter();
       LOG.debug("Testing compatibility of reader {} with writer {}.", reader, writer);
       final SchemaPairCompatibility result = checkReaderWriterCompatibility(reader, writer);
-      assertEquals(String.format("Expecting reader %s to be compatible with writer %s, but tested incompatible.",
-          reader, writer), SchemaCompatibilityType.COMPATIBLE, result.getType());
+      assertEquals(SchemaCompatibilityType.COMPATIBLE, result.getType(), String
+          .format("Expecting reader %s to be compatible with writer %s, but tested incompatible.", reader, writer));
     }
   }
 
@@ -469,7 +483,7 @@ public class TestSchemaCompatibility {
    * Tests the reader/writer compatibility at decoding time.
    */
   @Test
-  public void testReaderWriterDecodingCompatibility() throws Exception {
+  void readerWriterDecodingCompatibility() throws Exception {
     for (DecodingTestCase testCase : DECODING_COMPATIBILITY_TEST_CASES) {
       final Schema readerSchema = testCase.getReaderSchema();
       final Schema writerSchema = testCase.getWriterSchema();
@@ -492,10 +506,11 @@ public class TestSchemaCompatibility {
       final DatumReader<Object> datumReader = new GenericDatumReader<>(readerSchema);
       final Object decodedDatum = datumReader.read(null, decoder);
 
-      assertEquals(String.format(
-          "Expecting decoded value %s when decoding value %s whose writer schema is %s "
-              + "using reader schema %s, but value was %s.",
-          expectedDecodedDatum, datum, writerSchema, readerSchema, decodedDatum), expectedDecodedDatum, decodedDatum);
+      assertEquals(expectedDecodedDatum, decodedDatum,
+          String.format(
+              "Expecting decoded value %s when decoding value %s whose writer schema is %s "
+                  + "using reader schema %s, but value was %s.",
+              expectedDecodedDatum, datum, writerSchema, readerSchema, decodedDatum));
     }
   }
 
@@ -509,7 +524,7 @@ public class TestSchemaCompatibility {
   }
 
   @Test
-  public void checkResolvingDecoder() throws IOException {
+  void checkResolvingDecoder() throws IOException {
     final Schema locationSchema = readSchemaFromResources("schema-location.json");
     final Schema writeSchema = readSchemaFromResources("schema-location-write.json");
 
