@@ -27,13 +27,12 @@ import org.apache.avro.Schema;
 import org.apache.avro.Schema.Type;
 import org.apache.avro.generic.GenericDatumReader;
 import org.apache.avro.generic.GenericDatumWriter;
-import org.junit.Assert;
-import org.junit.Rule;
-import org.junit.Test;
-import org.junit.rules.TemporaryFolder;
+import org.junit.jupiter.api.Test;
+import org.junit.jupiter.api.io.TempDir;
 
 import java.io.BufferedOutputStream;
 import java.io.ByteArrayOutputStream;
+import java.io.File;
 import java.io.IOException;
 import java.io.OutputStream;
 import java.nio.ByteBuffer;
@@ -48,6 +47,7 @@ import java.nio.file.StandardOpenOption;
 import static java.util.Arrays.asList;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.is;
+import static org.junit.jupiter.api.Assertions.*;
 import static org.hamcrest.MatcherAssert.assertThat;
 
 public class TestEncoders {
@@ -56,76 +56,69 @@ public class TestEncoders {
 
   private static final EncoderFactory FACTORY = EncoderFactory.get();
 
-  @Rule
-  public TemporaryFolder DIR = new TemporaryFolder();
+  @TempDir
+  public Path dataDir;
 
   @Test
-  public void testBinaryEncoderInit() throws IOException {
+  void binaryEncoderInit() throws IOException {
     OutputStream out = new ByteArrayOutputStream();
     BinaryEncoder enc = FACTORY.binaryEncoder(out, null);
-    Assert.assertSame(enc, FACTORY.binaryEncoder(out, enc));
-  }
-
-  @Test(expected = NullPointerException.class)
-  public void testBadBinaryEncoderInit() {
-    FACTORY.binaryEncoder(null, null);
+    assertSame(enc, FACTORY.binaryEncoder(out, enc));
   }
 
   @Test
-  public void testBlockingBinaryEncoderInit() throws IOException {
+  void badBinaryEncoderInit() {
+    assertThrows(NullPointerException.class, () -> {
+      FACTORY.binaryEncoder(null, null);
+    });
+  }
+
+  @Test
+  void blockingBinaryEncoderInit() throws IOException {
     OutputStream out = new ByteArrayOutputStream();
     BinaryEncoder reuse = null;
     reuse = FACTORY.blockingBinaryEncoder(out, reuse);
-    Assert.assertSame(reuse, FACTORY.blockingBinaryEncoder(out, reuse));
-    // comparison
-  }
-
-  @Test(expected = NullPointerException.class)
-  public void testBadBlockintBinaryEncoderInit() {
-    OutputStream out = new ByteArrayOutputStream();
-
-    FACTORY.binaryEncoder(null, null);
-    BinaryEncoder enc = FACTORY.binaryEncoder(out, null);
-    Assert.assertSame(enc, FACTORY.binaryEncoder(out, enc));
-  }
-
-  @Test
-  public void blockingBinaryEncoderInit() throws IOException {
-    OutputStream out = new ByteArrayOutputStream();
-    BinaryEncoder reuse = null;
-    reuse = FACTORY.blockingBinaryEncoder(out, reuse);
-    Assert.assertSame(reuse, FACTORY.blockingBinaryEncoder(out, reuse));
+    assertSame(reuse, FACTORY.blockingBinaryEncoder(out, reuse));
     // comparison
   }
 
   @Test
-  public void testDirectBinaryEncoderInit() throws IOException {
-    OutputStream out = new ByteArrayOutputStream();
-    BinaryEncoder enc = FACTORY.directBinaryEncoder(out, null);
-    Assert.assertSame(enc, FACTORY.directBinaryEncoder(out, enc));
-  }
-
-  @Test(expected = NullPointerException.class)
-  public void testBadDirectBinaryEncoderInit() {
-    FACTORY.directBinaryEncoder(null, null);
+  void badBlockintBinaryEncoderInit() {
+    assertThrows(NullPointerException.class, () -> {
+      FACTORY.binaryEncoder(null, null);
+    });
   }
 
   @Test
-  public void testJsonEncoderInit() throws IOException {
+  void directBinaryEncoderInit() throws IOException {
     OutputStream out = new ByteArrayOutputStream();
     BinaryEncoder enc = FACTORY.directBinaryEncoder(out, null);
-    Assert.assertSame(enc, FACTORY.directBinaryEncoder(out, enc));
+    assertSame(enc, FACTORY.directBinaryEncoder(out, enc));
   }
 
   @Test
-  public void testBlokingDirectBinaryEncoderInit() throws IOException {
+  void badDirectBinaryEncoderInit() {
+    assertThrows(NullPointerException.class, () -> {
+      FACTORY.directBinaryEncoder(null, null);
+    });
+  }
+
+  @Test
+  void blockingDirectBinaryEncoderInit() throws IOException {
     OutputStream out = new ByteArrayOutputStream();
     BinaryEncoder enc = FACTORY.blockingDirectBinaryEncoder(out, null);
-    Assert.assertSame(enc, FACTORY.blockingDirectBinaryEncoder(out, enc));
+    assertSame(enc, FACTORY.blockingDirectBinaryEncoder(out, enc));
   }
 
   @Test
-  public void jsonEncoderInit() throws IOException {
+  void badBlockingDirectBinaryEncoderInit() {
+    assertThrows(NullPointerException.class, () -> {
+      FACTORY.blockingDirectBinaryEncoder(null, null);
+    });
+  }
+
+  @Test
+  void jsonEncoderInit() throws IOException {
     Schema s = new Schema.Parser().parse("\"int\"");
     OutputStream out = new ByteArrayOutputStream();
     FACTORY.jsonEncoder(s, out);
@@ -133,18 +126,22 @@ public class TestEncoders {
     enc.configure(out);
   }
 
-  @Test(expected = NullPointerException.class)
-  public void testBadJsonEncoderInitOS() throws IOException {
-    FACTORY.jsonEncoder(Schema.create(Type.INT), (OutputStream) null);
-  }
-
-  @Test(expected = NullPointerException.class)
-  public void testBadJsonEncoderInit() throws IOException {
-    FACTORY.jsonEncoder(Schema.create(Type.INT), (JsonGenerator) null);
+  @Test
+  void badJsonEncoderInitOS() throws IOException {
+    assertThrows(NullPointerException.class, () -> {
+      FACTORY.jsonEncoder(Schema.create(Type.INT), (OutputStream) null);
+    });
   }
 
   @Test
-  public void testJsonEncoderNewlineDelimited() throws IOException {
+  void badJsonEncoderInit() throws IOException {
+    assertThrows(NullPointerException.class, () -> {
+      FACTORY.jsonEncoder(Schema.create(Type.INT), (JsonGenerator) null);
+    });
+  }
+
+  @Test
+  void jsonEncoderNewlineDelimited() throws IOException {
     OutputStream out = new ByteArrayOutputStream();
     Schema ints = Schema.create(Type.INT);
     Encoder e = FACTORY.jsonEncoder(ints, out);
@@ -153,11 +150,11 @@ public class TestEncoders {
     writer.write(1, e);
     writer.write(2, e);
     e.flush();
-    Assert.assertEquals("1" + separator + "2", out.toString());
+    assertEquals("1" + separator + "2", out.toString());
   }
 
   @Test
-  public void testJsonEncoderWhenIncludeNamespaceOptionIsFalse() throws IOException {
+  void jsonEncoderWhenIncludeNamespaceOptionIsFalse() throws IOException {
     String value = "{\"b\": {\"string\":\"myVal\"}, \"a\": 1}";
     String schemaStr = "{\"type\": \"record\", \"name\": \"ab\", \"fields\": ["
         + "{\"name\": \"a\", \"type\": \"int\"}, {\"name\": \"b\", \"type\": [\"null\", \"string\"]}" + "]}";
@@ -165,12 +162,12 @@ public class TestEncoders {
     byte[] avroBytes = fromJsonToAvro(value, schema);
     ObjectMapper mapper = new ObjectMapper();
 
-    Assert.assertEquals(mapper.readTree("{\"b\":\"myVal\",\"a\":1}"),
+    assertEquals(mapper.readTree("{\"b\":\"myVal\",\"a\":1}"),
         mapper.readTree(fromAvroToJson(avroBytes, schema, false)));
   }
 
   @Test
-  public void testJsonEncoderWhenIncludeNamespaceOptionIsTrue() throws IOException {
+  void jsonEncoderWhenIncludeNamespaceOptionIsTrue() throws IOException {
     String value = "{\"b\": {\"string\":\"myVal\"}, \"a\": 1}";
     String schemaStr = "{\"type\": \"record\", \"name\": \"ab\", \"fields\": ["
         + "{\"name\": \"a\", \"type\": \"int\"}, {\"name\": \"b\", \"type\": [\"null\", \"string\"]}" + "]}";
@@ -178,12 +175,12 @@ public class TestEncoders {
     byte[] avroBytes = fromJsonToAvro(value, schema);
     ObjectMapper mapper = new ObjectMapper();
 
-    Assert.assertEquals(mapper.readTree("{\"b\":{\"string\":\"myVal\"},\"a\":1}"),
+    assertEquals(mapper.readTree("{\"b\":{\"string\":\"myVal\"},\"a\":1}"),
         mapper.readTree(fromAvroToJson(avroBytes, schema, true)));
   }
 
   @Test
-  public void testValidatingEncoderInit() throws IOException {
+  void validatingEncoderInit() throws IOException {
     Schema s = new Schema.Parser().parse("\"int\"");
     OutputStream out = new ByteArrayOutputStream();
     Encoder e = FACTORY.directBinaryEncoder(out, null);
@@ -191,32 +188,34 @@ public class TestEncoders {
   }
 
   @Test
-  public void testJsonRecordOrdering() throws IOException {
+  void jsonRecordOrdering() throws IOException {
     String value = "{\"b\": 2, \"a\": 1}";
     Schema schema = new Schema.Parser().parse("{\"type\": \"record\", \"name\": \"ab\", \"fields\": ["
         + "{\"name\": \"a\", \"type\": \"int\"}, {\"name\": \"b\", \"type\": \"int\"}" + "]}");
     GenericDatumReader<Object> reader = new GenericDatumReader<>(schema);
     Decoder decoder = DecoderFactory.get().jsonDecoder(schema, value);
     Object o = reader.read(null, decoder);
-    Assert.assertEquals("{\"a\": 1, \"b\": 2}", o.toString());
-  }
-
-  @Test(expected = AvroTypeException.class)
-  public void testJsonExcessFields() throws IOException {
-    String value = "{\"b\": { \"b3\": 1.4, \"b2\": 3.14, \"b1\": \"h\"}, \"a\": {\"a0\": 45, \"a2\":true, \"a1\": null}}";
-    Schema schema = new Schema.Parser().parse("{\"type\": \"record\", \"name\": \"ab\", \"fields\": [\n"
-        + "{\"name\": \"a\", \"type\": {\"type\":\"record\",\"name\":\"A\",\"fields\":\n"
-        + "[{\"name\":\"a1\", \"type\":\"null\"}, {\"name\":\"a2\", \"type\":\"boolean\"}]}},\n"
-        + "{\"name\": \"b\", \"type\": {\"type\":\"record\",\"name\":\"B\",\"fields\":\n"
-        + "[{\"name\":\"b1\", \"type\":\"string\"}, {\"name\":\"b2\", \"type\":\"float\"}, {\"name\":\"b3\", \"type\":\"double\"}]}}\n"
-        + "]}");
-    GenericDatumReader<Object> reader = new GenericDatumReader<>(schema);
-    Decoder decoder = DecoderFactory.get().jsonDecoder(schema, value);
-    reader.read(null, decoder);
+    assertEquals("{\"a\": 1, \"b\": 2}", o.toString());
   }
 
   @Test
-  public void testJsonRecordOrdering2() throws IOException {
+  void jsonExcessFields() throws IOException {
+    assertThrows(AvroTypeException.class, () -> {
+      String value = "{\"b\": { \"b3\": 1.4, \"b2\": 3.14, \"b1\": \"h\"}, \"a\": {\"a0\": 45, \"a2\":true, \"a1\": null}}";
+      Schema schema = new Schema.Parser().parse("{\"type\": \"record\", \"name\": \"ab\", \"fields\": [\n"
+          + "{\"name\": \"a\", \"type\": {\"type\":\"record\",\"name\":\"A\",\"fields\":\n"
+          + "[{\"name\":\"a1\", \"type\":\"null\"}, {\"name\":\"a2\", \"type\":\"boolean\"}]}},\n"
+          + "{\"name\": \"b\", \"type\": {\"type\":\"record\",\"name\":\"B\",\"fields\":\n"
+          + "[{\"name\":\"b1\", \"type\":\"string\"}, {\"name\":\"b2\", \"type\":\"float\"}, {\"name\":\"b3\", \"type\":\"double\"}]}}\n"
+          + "]}");
+      GenericDatumReader<Object> reader = new GenericDatumReader<>(schema);
+      Decoder decoder = DecoderFactory.get().jsonDecoder(schema, value);
+      reader.read(null, decoder);
+    });
+  }
+
+  @Test
+  void jsonRecordOrdering2() throws IOException {
     String value = "{\"b\": { \"b3\": 1.4, \"b2\": 3.14, \"b1\": \"h\"}, \"a\": {\"a2\":true, \"a1\": null}}";
     Schema schema = new Schema.Parser().parse("{\"type\": \"record\", \"name\": \"ab\", \"fields\": [\n"
         + "{\"name\": \"a\", \"type\": {\"type\":\"record\",\"name\":\"A\",\"fields\":\n"
@@ -227,12 +226,12 @@ public class TestEncoders {
     GenericDatumReader<Object> reader = new GenericDatumReader<>(schema);
     Decoder decoder = DecoderFactory.get().jsonDecoder(schema, value);
     Object o = reader.read(null, decoder);
-    Assert.assertEquals("{\"a\": {\"a1\": null, \"a2\": true}, \"b\": {\"b1\": \"h\", \"b2\": 3.14, \"b3\": 1.4}}",
+    assertEquals("{\"a\": {\"a1\": null, \"a2\": true}, \"b\": {\"b1\": \"h\", \"b2\": 3.14, \"b3\": 1.4}}",
         o.toString());
   }
 
   @Test
-  public void testJsonRecordOrderingWithProjection() throws IOException {
+  void jsonRecordOrderingWithProjection() throws IOException {
     String value = "{\"b\": { \"b3\": 1.4, \"b2\": 3.14, \"b1\": \"h\"}, \"a\": {\"a2\":true, \"a1\": null}}";
     Schema writerSchema = new Schema.Parser().parse("{\"type\": \"record\", \"name\": \"ab\", \"fields\": [\n"
         + "{\"name\": \"a\", \"type\": {\"type\":\"record\",\"name\":\"A\",\"fields\":\n"
@@ -246,11 +245,11 @@ public class TestEncoders {
     GenericDatumReader<Object> reader = new GenericDatumReader<>(writerSchema, readerSchema);
     Decoder decoder = DecoderFactory.get().jsonDecoder(writerSchema, value);
     Object o = reader.read(null, decoder);
-    Assert.assertEquals("{\"a\": {\"a1\": null, \"a2\": true}}", o.toString());
+    assertEquals("{\"a\": {\"a1\": null, \"a2\": true}}", o.toString());
   }
 
   @Test
-  public void testJsonRecordOrderingWithProjection2() throws IOException {
+  void jsonRecordOrderingWithProjection2() throws IOException {
     String value = "{\"b\": { \"b1\": \"h\", \"b2\": [3.14, 3.56], \"b3\": 1.4}, \"a\": {\"a2\":true, \"a1\": null}}";
     Schema writerSchema = new Schema.Parser().parse("{\"type\": \"record\", \"name\": \"ab\", \"fields\": [\n"
         + "{\"name\": \"a\", \"type\": {\"type\":\"record\",\"name\":\"A\",\"fields\":\n"
@@ -264,19 +263,19 @@ public class TestEncoders {
     GenericDatumReader<Object> reader = new GenericDatumReader<>(writerSchema, readerSchema);
     Decoder decoder = DecoderFactory.get().jsonDecoder(writerSchema, value);
     Object o = reader.read(null, decoder);
-    Assert.assertEquals("{\"a\": {\"a1\": null, \"a2\": true}}", o.toString());
+    assertEquals("{\"a\": {\"a1\": null, \"a2\": true}}", o.toString());
   }
 
   @Test
-  public void testArrayBackedByteBuffer() throws IOException {
+  void arrayBackedByteBuffer() throws IOException {
     ByteBuffer buffer = ByteBuffer.wrap(someBytes(EXAMPLE_DATA_SIZE));
 
     testWithBuffer(buffer);
   }
 
   @Test
-  public void testMappedByteBuffer() throws IOException {
-    Path file = Paths.get(DIR.getRoot().getPath() + "testMappedByteBuffer.avro");
+  void mappedByteBuffer() throws IOException {
+    Path file = dataDir.resolve("testMappedByteBuffer.avro");
     Files.write(file, someBytes(EXAMPLE_DATA_SIZE));
     MappedByteBuffer buffer = FileChannel.open(file, StandardOpenOption.READ).map(FileChannel.MapMode.READ_ONLY, 0,
         EXAMPLE_DATA_SIZE);
@@ -349,4 +348,35 @@ public class TestEncoders {
 
     return new String(output.toByteArray(), StandardCharsets.UTF_8.name());
   }
+
+  @Test
+  public void testJsonEncoderInitAutoFlush() throws IOException {
+    Schema s = new Schema.Parser().parse("\"int\"");
+    OutputStream baos = new ByteArrayOutputStream();
+    OutputStream out = new BufferedOutputStream(baos);
+    JsonEncoder enc = FACTORY.jsonEncoder(s, out, false);
+    enc.configure(out, false);
+    enc.writeInt(24);
+    enc.flush();
+    assertEquals("", baos.toString());
+    out.flush();
+    assertEquals("24", baos.toString());
+  }
+
+  @Test
+  public void testJsonEncoderInitAutoFlushDisabled() throws IOException {
+    ByteArrayOutputStream baos = new ByteArrayOutputStream();
+    OutputStream out = new BufferedOutputStream(baos);
+    Schema ints = Schema.create(Type.INT);
+    Encoder e = FACTORY.jsonEncoder(ints, out, false, false);
+    String separator = System.getProperty("line.separator");
+    GenericDatumWriter<Integer> writer = new GenericDatumWriter<Integer>(ints);
+    writer.write(1, e);
+    writer.write(2, e);
+    e.flush();
+    assertEquals("", baos.toString());
+    out.flush();
+    assertEquals("1" + separator + "2", baos.toString());
+    out.close();
+  }
 }
